package cn.com.infosec.asn1.cmp;

import cn.com.infosec.asn1.ASN1Choice;
import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.x509.X509CertificateStructure;

public class CMPCertificate extends ASN1Encodable implements ASN1Choice {
   private X509CertificateStructure x509v3PKCert;

   public CMPCertificate(X509CertificateStructure x509v3PKCert) {
      if (x509v3PKCert.getVersion() == 2) {
         this.x509v3PKCert = x509v3PKCert;
      } else {
         throw new IllegalArgumentException("only version 3 certificates allowed");
      }
   }

   public static CMPCertificate getInstance(Object o) {
      if (o instanceof CMPCertificate) {
         return (CMPCertificate)o;
      } else if (o instanceof X509CertificateStructure) {
         return new CMPCertificate((X509CertificateStructure)o);
      } else if (o instanceof ASN1Sequence) {
         return new CMPCertificate(X509CertificateStructure.getInstance(o));
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   public X509CertificateStructure getX509v3PKCert() {
      return this.x509v3PKCert;
   }

   public DERObject toASN1Object() {
      return this.x509v3PKCert.toASN1Object();
   }
}
